@@ -66,6 +66,15 @@ Nest bit operations!::
         MonthEvents('active', now.year, now.month)
     )
 
+As something new tracking hourly is disabled (to save memory!) To enable it as default do::
+
+    import bitmapist
+    bitmapist.TRACK_HOURLY = True
+
+Additionally you can supply an extra argument to mark_event to bypass the default value::
+
+    mark_event('active', 123, track_hourly=False)
+
 :copyright: 2012 by Doist Ltd.
 :developer: Amir Salihefendic ( http://amix.dk )
 :license: BSD
@@ -81,6 +90,11 @@ SYSTEMS = {
     'default': redis.Redis(host='localhost', port=6379)
 }
 
+# Should hourly be tracked as default?
+# Note that this can have huge implications in amounts
+# of memory that Redis uses (especially with huge integers)
+TRACK_HOURLY = False
+
 def setup_redis(name, host, port, **kw):
     """
     Setup a redis system.
@@ -108,7 +122,7 @@ def get_redis(system='default'):
 
 
 #--- Events marking and deleting ----------------------------------------------
-def mark_event(event_name, uuid, system='default', now=None):
+def mark_event(event_name, uuid, system='default', now=None, track_hourly=None):
     """
     Marks an event for hours, days, weeks and months.
 
@@ -116,6 +130,7 @@ def mark_event(event_name, uuid, system='default', now=None):
     :param :uuid An unique id, typically user id. The id should not be huge, read Redis documentation why (bitmaps)
     :param :system The Redis system to use
     :param :now Which date should be used as a reference point, default is `datetime.utcnow`
+    :param :track_hourly Should hourly stats be tracked, defaults to bitmapist.TRACK_HOURLY, but an be changed
 
     Examples::
 
@@ -125,6 +140,9 @@ def mark_event(event_name, uuid, system='default', now=None):
         # Mark task completed for id 252
         mark_event('tasks:completed', 252)
     """
+    if track_hourly == None:
+        track_hourly = TRACK_HOURLY
+
     if not now:
         now = datetime.utcnow()
 
@@ -132,13 +150,14 @@ def mark_event(event_name, uuid, system='default', now=None):
         MonthEvents(event_name, now.year, now.month),
         WeekEvents(event_name, now.year, now.isocalendar()[1]),
         DayEvents(event_name, now.year, now.month, now.day),
-        HourEvents(event_name, now.year, now.month, now.day, now.hour)
+        HourEvents(event_name, now.year, now.month, now.day, now.hour) if track_hourly else None
     )
 
     with get_redis(system).pipeline() as p:
         p.multi()
         for obj in stat_objs:
-            p.setbit(obj.redis_key, uuid, 1)
+            if obj != None:
+                p.setbit(obj.redis_key, uuid, 1)
         p.execute()
 
 
@@ -163,6 +182,17 @@ def delete_temporary_bitop_keys(system='default'):
 
 
 #--- Events ----------------------------------------------
+class MixinEventsMarked:
+    """
+    Extends with an obj.has_events_marked()
+    that returns `True` if there are any events marked,
+    otherwise `False` is returned.
+    """
+    def has_events_marked(self):
+        cli = get_redis(self.system)
+        return cli.get(self.redis_key) != None
+
+
 class MixinCounts:
     """
     Extends with an obj.get_count() that uses BITCOUNT to
@@ -193,7 +223,7 @@ class MixinContains:
             return False
 
 
-class MonthEvents(MixinCounts, MixinContains):
+class MonthEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a month.
 
@@ -207,7 +237,7 @@ class MonthEvents(MixinCounts, MixinContains):
                                      '%s-%s' % (year, month))
 
 
-class WeekEvents(MixinCounts, MixinContains):
+class WeekEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a week.
 
@@ -220,7 +250,7 @@ class WeekEvents(MixinCounts, MixinContains):
         self.redis_key = _prefix_key(event_name, 'W%s-%s' % (year, week))
 
 
-class DayEvents(MixinCounts, MixinContains):
+class DayEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a day.
 
@@ -234,7 +264,7 @@ class DayEvents(MixinCounts, MixinContains):
                                      '%s-%s-%s' % (year, month, day))
 
 
-class HourEvents(MixinCounts, MixinContains):
+class HourEvents(MixinCounts, MixinContains, MixinEventsMarked):
     """
     Events for a hour.
 
